# Envoy
> A .env file validator

## Why
It can be very easy when using a .env file for secrets that it eventually falls out of sync with it's .env.example counterpart. Doubly so when working on multiple machines or with multiple developers. This tool makes easier to use .env files more rigidly and validate some set criteria without needing to setup something like a Secrets Management Tool which is often overkill.

## Features
- 🪄 Check for missing env vars from an example file
- 🚫 Optionally warn for uninitialised variables
- 🆕 Optionally warn for additional variables

## Installation
<todo when package is published>

